//+------------------------------------------------------------------+
//|                                                  Custom MACD.mq4 |
//|                      Copyright  2004, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+
// Time frame enumeration
// Constant    Value Description 
// PERIOD_M1   1     1 minute. 
// PERIOD_M5   5     5 minutes. 
// PERIOD_M15  15    15 minutes. 
// PERIOD_M30  30    30 minutes. 
// PERIOD_H1   60    1 hour. 
// PERIOD_H4   240   4 hour. 
// PERIOD_D1   1440  Daily. 
// PERIOD_W1   10080 Weekly. 
// PERIOD_MN1  43200 Monthly. 
// 0 (zero) 0 Time frame used on the chart. 
//
// Moving Average method enumeration
// Constant    Value    Description 
// MODE_SMA    0        Simple moving average, 
// MODE_EMA    1        Exponential moving average, 
// MODE_SMMA   2        Smoothed moving average, 
// MODE_LWMA   3        Linear weighted moving average. 
//
// Applied price enumeration
// Constant       Value    Description 
// PRICE_CLOSE    0        Close price. 
// PRICE_OPEN     1        Open price. 
// PRICE_HIGH     2        High price. 
// PRICE_LOW      3        Low price. 
// PRICE_MEDIAN   4        Median price, (high+low)/2. 
// PRICE_TYPICAL  5        Typical price, (high+low+close)/3. 
// PRICE_WEIGHTED 6        Weighted close price, (high+low+close+close)/4. 

#property  copyright "Copyright  2004, MetaQuotes Software Corp."
#property  link      "http://www.metaquotes.net/"

//---- indicator settings
#property  indicator_separate_window
#property  indicator_buffers 2
#property  indicator_color1  Silver
#property  indicator_color2  Yellow

//---- indicator parameters
extern int Time_Period = PERIOD_W1;

extern int Fast_MA = 5;
extern int Fast_Type = MODE_SMA;
extern int Fast_Applied_Price = PRICE_MEDIAN;

extern int Slow_MA = 21;
extern int Slow_Type = MODE_EMA;
extern int Slow_Applied_Price = PRICE_MEDIAN;

//---- indicator buffers
double     ind_buffer1[];
double     ind_buffer2[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- drawing settings
   SetIndexStyle(0,DRAW_NONE);
   SetIndexStyle(1,DRAW_HISTOGRAM,STYLE_SOLID,5);
   SetIndexDrawBegin(1,Slow_MA);
   IndicatorDigits(MarketInfo(Symbol(),MODE_DIGITS)+1);

//---- indicator buffers mapping
   if(!SetIndexBuffer(0,ind_buffer1) && !SetIndexBuffer(1,ind_buffer2))
      Print("cannot set indicator buffers!");

//---- name for DataWindow and indicator subwindow label
   IndicatorShortName("MACD(" + Time_Period + "," + Fast_MA + "," + Slow_MA + ")");
   SetIndexLabel(0,"MACD");
   SetIndexLabel(1,"Signal");

//---- initialization done
   return(0);
  }

//+------------------------------------------------------------------+
//| Moving Averages Convergence/Divergence                           |
//+------------------------------------------------------------------+
int start()
  {
   int limit;
   int counted_bars=IndicatorCounted();

//---- check for possible errors
   if(counted_bars<0) return(-1);

//---- last counted bar will be recounted
   if(counted_bars>0) counted_bars--;
   limit=Bars-counted_bars;

//---- macd counted in the 1-st buffer
   for(int i=0; i<limit; i++)
      ind_buffer1[i]=iMA(NULL,Time_Period,Fast_MA,0,Fast_Type,Fast_Applied_Price,i)-iMA(NULL,Time_Period,Slow_MA,0,Slow_Type,Slow_Applied_Price,i);

//---- signal line counted in the 2-nd buffer
   for(i=0; i<limit; i++)
      ind_buffer2[i]=(ind_buffer1[i]-ind_buffer1[i+1])*10000;
//---- done
   return(0);
  }